core:module("PlatformManager")
core:import("CoreEvent")

function WinPlatformManager:set_rich_presence(name)
	self._current_rich_presence = name

	if SystemInfo:distribution() == Idstring("STEAM") and not Global.game_settings.single_player then
		if name == "Idle" then
			Steam:set_rich_presence("status", "")
			Steam:set_rich_presence("steam_display", "")
		else
			local rich_presence_allowed = true
			rich_presence_allowed = rich_presence_allowed and Global.game_settings.permission ~= "private"

			if not rich_presence_allowed then
				Steam:set_rich_presence("status", "")
				Steam:set_rich_presence("steam_display", "")

				return
			end

			local in_lobby = _G.game_state_machine:verify_game_state(_G.GameStateFilters.lobby)
			local is_multi_day = #(managers.job:current_job_chain_data() or {}) > 1
			local job_tweak = managers.job:current_job_data()
			local display_token = nil
			local heist_token = job_tweak and job_tweak.name_id
			local difficulty = nil
			local heist_day = is_multi_day and tostring(managers.job:current_stage())
			local peer_count = tostring(#managers.network:session():all_peers())
			local max_peers = tostring(_G.tweak_data.max_players)
            local lobby_id = nil
            
            if managers.network and managers.network.matchmake and managers.network.matchmake.lobby_handler then
                lobby_id = managers.network.matchmake.lobby_handler:id()
            end
            
			local crime_spree_rank = nil

			if in_lobby and job_tweak then
				display_token = "#in_lobby_heist"
			elseif in_lobby then
				display_token = "#in_lobby"
			elseif job_tweak and is_multi_day then
				display_token = "#in_heist_multi_day"
			elseif job_tweak then
				display_token = "#in_heist_one_day"
			end

			if managers.job:has_active_job() then
				local difficulty_stars = managers.job:current_difficulty_stars()
				difficulty = tostring(difficulty_stars)
			end

			if not in_lobby and managers.crime_spree and managers.crime_spree:is_active() then
				local level_id = Global.game_settings.level_id
				local name_id = level_id and _G.tweak_data.levels[level_id] and _G.tweak_data.levels[level_id].name_id

				if name_id then
					heist_token = name_id or heist_token
				end

				display_token = display_token .. "_cs"
				crime_spree_rank = managers.experience:cash_string(managers.crime_spree:spree_level(), "")
				difficulty = nil
			end

			local rp_pairs = {
				day = heist_day or "",
				difficulty = difficulty or "",
				heist_token = heist_token or "",
				max_peers = max_peers,
				steam_display = display_token or "",
				steam_player_group = lobby_id or "",
				steam_player_group_size = peer_count,
				crime_spree_rank = crime_spree_rank or "",
				status = self:_build_legacy_presence_string()
			}

			for key, value in pairs(rp_pairs) do
				Steam:set_rich_presence(key, value)
			end
		end
	end

	self:set_rich_presence_discord(name)
end